# babel-extract-comments [![NPM version](https://img.shields.io/npm/v/babel-extract-comments.svg)](https://www.npmjs.com/package/babel-extract-comments) [![Build Status](https://img.shields.io/travis/jonschlinkert/babel-extract-comments.svg)](https://travis-ci.org/jonschlinkert/babel-extract-comments)

> Uses babel to extract JavaScript code comments from a string. Returns an array of comment objects, with line, column, index, comment type and comment string.

- [Install](#install)
- [API](#api)
  * [Transform function](#transform-function)
- [Example results](#example-results)
- [Related projects](#related-projects)
- [Running tests](#running-tests)
- [Contributing](#contributing)
- [Author](#author)
- [License](#license)

_(TOC generated by [verb](https://github.com/verbose/verb) using [markdown-toc](https://github.com/jonschlinkert/markdown-toc))_

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm i babel-extract-comments --save
```

## API

**Params**

* `string` **{String}**: String of javascript
* `fn` **{Function}**: Optional. Functionto transform commend objects (AST tokens)
* `returns` **{Object}**: Object of code comments.

**Example**

```js
var extract = require('babel-extract-comments');
extract('// this is a code comment');
```

### Transform function

Optionally pass a function as the second argument to transform comment objects.

```js
var comments = extract(javascriptString, function(comment) {
  comment.foo = 'bar';
});
console.log(comments[0].foo);
//=> 'bar';
```

## Example results

See [fixtures/app.js](./fixtures/app.js) to see the code comments used to generate the following:

```js
[{ type: 'Block',
  value: '*\n * Create an instance of App with `options`.\n *\n * @param {Object} options\n * @api public\n ',
  range: [ 15, 112 ],
  loc: { 
    start: { line: 3, column: 0 }, 
    end: { line: 8, column: 3 } } 
}]
```

## Related projects

* [esprima-extract-comments](https://www.npmjs.com/package/esprima-extract-comments): Extract code comments from string or from a glob of files using esprima. | [homepage](https://github.com/jonschlinkert/esprima-extract-comments)
* [extract-comments](https://www.npmjs.com/package/extract-comments): Uses esprima to extract line and block comments from a string of JavaScript. Also optionally… [more](https://www.npmjs.com/package/extract-comments) | [homepage](https://github.com/jonschlinkert/extract-comments)
* [js-comments](https://www.npmjs.com/package/js-comments): Parse JavaScript code comments and generate API documentation. | [homepage](https://github.com/jonschlinkert/js-comments)
* [parse-comments](https://www.npmjs.com/package/parse-comments): Parse code comments from JavaScript or any language that uses the same format. | [homepage](https://github.com/jonschlinkert/parse-comments)

## Running tests

Install dev dependencies:

```sh
$ npm i -d && npm test
```

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/jonschlinkert/babel-extract-comments/issues/new).

## Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2015 [Jon Schlinkert](https://github.com/jonschlinkert)
Released under the MIT license.

***

_This file was generated by [verb](https://github.com/verbose/verb) on December 30, 2015._